@@ -51,7 +51,7 @@ Knet <- function(X, r = NULL, freq, ..., verbose = FALSE) {
   noVert <- npoints(vertices(L))
   PL <- as.psp(L)
   noEdge <- nobjects(PL)
-  EdgeLengths <- lengths.psp(PL)
+  EdgeLengths <- lengths_psp(PL)
   Vert1 <- L$from
   Vert2 <- L$to
   ## call C code
